==> 0.0.14.tar.gz: lib/layout/gateway.dart <==
import 'package:bmi_global/bmi_global.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class GateWayPage<U extends AuthUser, A extends AuthProvider<U>, R extends AppRoute,
    I extends AppInfoProvider> extends StatelessWidget {
  final Widget? child;

  const GateWayPage.build(BuildContext context, this.child, {Key? key})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    final appInfoProvider = Provider.of<I>(context);
    if (appInfoProvider.isNew) {
      if (appInfoProvider.apkAvalable) {
        return Scaffold(
          appBar: AppBar(title: const Text("New App Version Avalable")),
          body: Center(
            child: ElevatedButton.icon(
              onPressed: appInfoProvider.openApk,
              label: const Text("Install"),
              icon: const Icon(Icons.install_mobile),
            ),
          ),
        );
      }
      if (appInfoProvider.downloading) {
        return Scaffold(
          appBar: AppBar(title: const Text("New App Version Avalable")),
          body: Column(
            children: [
              LinearProgressIndicator(value: appInfoProvider.progress),
              Expanded(
                child: Center(
                  child: Text(
                    "Data Downloaded: \n${(appInfoProvider.progress * 100).toStringAsFixed(2)}%",
                    style: Theme.of(context).textTheme.headline5,
                  ),
                ),
              )
            ],
          ),
        );
      }
      return Scaffold(
        appBar: AppBar(title: const Text("New App Version Avalable")),
        body: Center(
          child: ElevatedButton.icon(
            onPressed: appInfoProvider.download,
            label: const Text("Download"),
            icon: const Icon(Icons.download),
          ),
        ),
      );
    }
    final authProvider = Provider.of<A>(context);
    final user = authProvider.user;
    if (user == null) {
      if (authProvider.loading) {
        return Scaffold(
          appBar: AppBar(
            title: const Text("Loading Auth"),
            actions: [
              IconButton(
                onPressed: authProvider.logOut,
                icon: const Icon(Icons.logout_rounded),
              )
            ],
          ),
          body: const CircularProgressIndicator(),
        );
      }
      return Scaffold(
        appBar: AppBar(title: const Text("Log-In Page")),
        body: Center(
          child: TextButton.icon(
            onPressed: authProvider.login,
            icon: const Icon(Icons.login),
            label: const Text("Log In"),
          ),
        ),
      );
    }
    final config = Provider.of<ConfigProvider>(context, listen: false);
    return ProxyProvider<AuthProvider, AuthUser>(
      update: (context, auth, previous) {
        return auth.user ?? user;
      },
      create: (_) => user,
      child: config.finalGateway(
        context,
        child ??
            config.defaultRoute.builder(context, argument: null) ??
            config.build404Page(context),
      ),
    );
  }
}

==> 0.0.18.tar.gz: lib/layout/gateway.dart <==
import 'package:bmi_global/bmi_global.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class GateWayPage<U extends AuthUser, A extends AuthProvider<U>,
    R extends AppRoute, I extends AppInfoProvider> extends StatelessWidget {
  final Widget? child;

  const GateWayPage.build(BuildContext context, this.child, {Key? key})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    final appInfoProvider = Provider.of<I>(context);
    if (appInfoProvider.isNew) {
      if (appInfoProvider.apkAvalable) {
        return Scaffold(
          appBar: AppBar(title: const Text("New App Version Avalable")),
          body: Center(
            child: ElevatedButton.icon(
              onPressed: appInfoProvider.openApk,
              label: const Text("Install"),
              icon: const Icon(Icons.install_mobile),
            ),
          ),
        );
      }
      if (appInfoProvider.downloading) {
        return Scaffold(
          appBar: AppBar(title: const Text("New App Version Avalable")),
          body: Column(
            children: [
              LinearProgressIndicator(value: appInfoProvider.progress),
              Expanded(
                child: Center(
                  child: Text(
                    "Data Downloaded: \n${(appInfoProvider.progress * 100).toStringAsFixed(2)}%",
                    style: Theme.of(context).textTheme.headline5,
                  ),
                ),
              )
            ],
          ),
        );
      }
      return Scaffold(
        appBar: AppBar(title: const Text("New App Version Avalable")),
        body: Center(
          child: ElevatedButton.icon(
            onPressed: appInfoProvider.download,
            label: const Text("Download"),
            icon: const Icon(Icons.download),
          ),
        ),
      );
    }
    final authProvider = Provider.of<A>(context);
    final user = authProvider.user;
    if (user == null) {
      if (authProvider.loading) {
        return Scaffold(
          appBar: AppBar(
            title: const Text("Loading Auth"),
            actions: [
              IconButton(
                onPressed: authProvider.logOut,
                icon: const Icon(Icons.logout_rounded),
              )
            ],
          ),
          body: const Center(child: CircularProgressIndicator()),
        );
      }
      return Scaffold(
        appBar: AppBar(title: const Text("Log-In Page")),
        body: Center(
          child: TextButton.icon(
            onPressed: authProvider.login,
            icon: const Icon(Icons.login),
            label: const Text("Log In"),
          ),
        ),
      );
    }
    final config = Provider.of<ConfigProvider>(context, listen: false);
    return ProxyProvider<A, U>(
      update: (context, auth, previous) {
        return auth.user ?? user;
      },
      create: (_) => user,
      child: config.finalGateway(
        context,
        child ??
            config.defaultRoute.builder(context, argument: null) ??
            config.build404Page(context),
      ),
    );
  }
}
